# Set Up User Access
### On this page
  * [Explore Authentication and Authorization Options](https://help.sap.com/docs/leanix/ea/set-up-user-access#explore-authentication-and-authorization-options)
  * [Access Your Workspace](https://help.sap.com/docs/leanix/ea/set-up-user-access#access-your-workspace)
  * [Invite the Core Team](https://help.sap.com/docs/leanix/ea/set-up-user-access#invite-the-core-team)
  * [Set Up Single Sign-On (SSO)](https://help.sap.com/docs/leanix/ea/set-up-user-access#set-up-single-sign-on-\(sso\))
  * [Manage Roles and Permissions](https://help.sap.com/docs/leanix/ea/set-up-user-access#manage-roles-and-permissions)


Invite users to your workspace and manage their access permissions.
